@@ -1,4 +1,5 @@
 __all__ = [
+    "str_c",
     "str_count",
     "str_detect",
     "str_extract",
@@ -21,6 +22,50 @@ from numpy import NaN, isnan
 # - a straight port of stringr
 # ------------------------------------------------------------------------------
 
+## Vectorized Concatenate
+# --------------------------------------------------
+def _vec_len(x):
+    try:
+        if isinstance(x, str):
+            raise TypeError
+        return len(x)
+    except TypeError:
+        return 1
+
+
+def _ensure_series(x, l, length):
+    if (l == 1) and (not isinstance(x, Series)):
+        return Series([x] * length).astype(str)
+
+    return Series(x).astype(str).reset_index(drop=True)
+
+
+@make_symbolic
+def str_c(*args, sep=""):
+    """
+    Concatenate strings
+    """
+    ## Pass-through a single arg
+    if len(args) < 2:
+        return Series(args[0]).astype(str)
+
+    ## Check all lengths 1 or equal
+    all_lengths = [_vec_len(a) for a in args]
+    if not len(set(filter(lambda l: l > 1, all_lengths))) <= 1:
+        raise ValueError("All arguments must be same length or scalar")
+    length = max(all_lengths)
+
+    ## Ensure first arg is string
+    res = _ensure_series(args[0], all_lengths[0], length)
+
+    ## Iteratively concatenate
+    for i in range(1, len(args)):
+        tmp = _ensure_series(args[i], all_lengths[i], length)
+        res = res.str.cat(tmp, sep=sep)
+
+    return res
+
+
 ## Detect matches
 # --------------------------------------------------
 @make_symbolic
@@ -138,17 +183,13 @@ def str_replace(string, pattern, replacement):
     try:
         if isinstance(string, str):
             raise TypeError
-        return Series(
-            [
-                re.sub(pattern, replacement, s, count=1)
-                for s in string
-            ]
-        )
+        return Series([re.sub(pattern, replacement, s, count=1) for s in string])
 
     except TypeError:
 
         return re.sub(pattern, replacement, string, count=1)
 
+
 @make_symbolic
 def str_replace_all(string, pattern, replacement):
     """Replace all occurences of pattern in each string."""
@@ -156,12 +197,7 @@ def str_replace_all(string, pattern, replacement):
     try:
         if isinstance(string, str):
             raise TypeError
-        return Series(
-            [
-                re.sub(pattern, replacement, s)
-                for s in string
-            ]
-        )
+        return Series([re.sub(pattern, replacement, s) for s in string])
 
     except TypeError:
 
@@ -189,12 +225,7 @@ def str_split(string, pattern, maxsplit=0):
     try:
         if isinstance(string, str):
             raise TypeError
-        return Series(
-            [
-                re.split(pattern, s, maxsplit=maxsplit)
-                for s in string
-            ]
-        )
+        return Series([re.split(pattern, s, maxsplit=maxsplit) for s in string])
 
     except TypeError:
 
